# CHANGELOG

<!-- version list -->

## v1.1.1 (2026-02-19)

### Bug Fixes

- Clean up stale recipe, update README, remove dead code, fix imports
  ([`adfa071`](https://github.com/philipnickel/dtu-env/commit/adfa071427c830952b0e37e2cf62e4e36fc8565a))


## v1.1.0 (2026-02-18)

### Features

- Replace Textual TUI with simple interactive CLI using simple-term-menu
  ([`7832853`](https://github.com/philipnickel/dtu-env/commit/7832853d82a4423a6803a6f61e83b7ca3da41d65))


## v1.0.1 (2026-02-18)

### Bug Fixes

- Rename workflow to publish.yml to match PyPI trusted publisher config
  ([`1161707`](https://github.com/philipnickel/dtu-env/commit/11617079ff6816755f1480aa50efaa90b9b9070b))


## v1.0.0 (2026-02-18)

### Features

- Add automated semantic versioning and PyPI publishing
  ([`0784b5e`](https://github.com/philipnickel/dtu-env/commit/0784b5efe0fb1695b6e7a34e38f8599efefe655f))


## v0.1.0 (2026-02-18)

- Initial Release
